from tradingfeatures.apis.bitfinex import bitfinex
from tradingfeatures.apis.bitstamp import bitstamp
from tradingfeatures.apis.bitmex import bitmex
from tradingfeatures.apis.binance import binance
# from tradingfeatures.apis.okex import okex

# from tradingfeatures.apis.bitmex_v3 import bitmexV3